@@ -22,13 +22,14 @@ class WebEnginePage(QWebEnginePage):
 
 application= QApplication(sys.argv)
 @click.group()
-@click.version_option('0.1.5')
+@click.version_option('0.2.1')
+
 def main():
     """RSB - webpages in GUI VIEW"""
     pass
 
 
-@main.command('open')
+@main.command('open', help='"rsb open <url>" opens your desired URL in RSB window')
 @click.argument('url', nargs=1)
 def open(url):
     webpage = WebEnginePage()
